@@ -1177,9 +1177,10 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
   {
     r->headers_out.status = http_status = mp4_process(context);
 
+    headers_t* headers = context->headers_;
     buckets_t* buckets = context->buckets_;
 
-    if(buckets->x_usp_header1[0])
+    if(headers->x_usp_header1[0])
     {
       ngx_table_elt_t* h = ngx_list_push(&r->headers_out.headers);
       if(h == NULL)
@@ -1190,11 +1191,11 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
 
       h->key.len = sizeof("X-USP-Info1") - 1;
       h->key.data = (u_char*)"X-USP-Info1";
-      h->value.len = strlen(buckets->x_usp_header1);
-      h->value.data = (u_char*)buckets->x_usp_header1;
+      h->value.len = strlen(headers->x_usp_header1);
+      h->value.data = (u_char*)headers->x_usp_header1;
     }
 
-    if(buckets->x_usp_header2[0])
+    if(headers->x_usp_header2[0])
     {
       ngx_table_elt_t* h = ngx_list_push(&r->headers_out.headers);
       if(h == NULL)
@@ -1205,14 +1206,14 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
 
       h->key.len = sizeof("X-USP-Info2") - 1;
       h->key.data = (u_char*)"X-USP-Info2";
-      h->value.len = strlen(buckets->x_usp_header2);
-      h->value.data = (u_char*)buckets->x_usp_header2;
+      h->value.len = strlen(headers->x_usp_header2);
+      h->value.data = (u_char*)headers->x_usp_header2;
     }
 
     // Add Last-Modified
-    if(buckets->updated_at_)
+    if(headers->updated_at_)
     {
-      r->headers_out.last_modified_time = buckets->updated_at_ / 1000000;
+      r->headers_out.last_modified_time = headers->updated_at_ / 1000000;
     }
 
     // compute expiry with seconds accuracy for interoperable results with nginx
@@ -1223,14 +1224,14 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
       ngx_str_t cache_control = ngx_null_string;
       ngx_str_t expires = ngx_null_string;
 
-      if(buckets->cache_control_)
+      if(headers->cache_control_)
       {
-        cache_control.len = strlen(buckets->cache_control_);
-        cache_control.data = (u_char*)buckets->cache_control_;
+        cache_control.len = strlen(headers->cache_control_);
+        cache_control.data = (u_char*)headers->cache_control_;
       }
-      else if(buckets->expires_at_)
+      else if(headers->expires_at_)
       {
-        seconds_t expires_time = buckets->expires_at_ / 1000000;
+        seconds_t expires_time = headers->expires_at_ / 1000000;
         seconds_t request_time = r->start_sec;
 
         // use expiry from backend only if it's at least a second ahead of request
@@ -1321,9 +1322,9 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
     }
 
     // Add Sunset header
-    if(buckets->sunset_at_)
+    if(headers->sunset_at_)
     {
-      seconds_t sunset_time = buckets->sunset_at_ / 1000000;
+      seconds_t sunset_time = headers->sunset_at_ / 1000000;
 
       ngx_table_elt_t* h = ngx_list_push(&r->headers_out.headers);
       if(h == NULL)
@@ -1344,7 +1345,7 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
     }
 
     // Add the link header for start/next
-    if(buckets->link_[0])
+    if(headers->link_[0])
     {
       ngx_table_elt_t* h = ngx_list_push(&r->headers_out.headers);
       if(h == NULL)
@@ -1356,8 +1357,8 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
 
       h->key.len = sizeof("Link") - 1;
       h->key.data = (u_char*)"Link";
-      h->value.len = strlen(buckets->link_);
-      h->value.data = (u_char*)buckets->link_;
+      h->value.len = strlen(headers->link_);
+      h->value.data = (u_char*)headers->link_;
     }
 
     // Set the content length
@@ -1380,7 +1381,7 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
     }
 
     // Add ETag header
-    if(buckets->etag_[0])
+    if(headers->etag_[0])
     {
       ngx_table_elt_t* etag = ngx_list_push(&r->headers_out.headers);
       if(etag == NULL)
@@ -1391,8 +1392,8 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
       etag->hash = 1;
       ngx_str_set(&etag->key, "ETag");
 
-      etag->value.len = strlen(buckets->etag_);
-      etag->value.data = (u_char*)buckets->etag_;
+      etag->value.len = strlen(headers->etag_);
+      etag->value.data = (u_char*)headers->etag_;
 
       r->headers_out.etag = etag;
     }
@@ -1416,8 +1417,8 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
     else
     {
       // Set the content type
-      r->headers_out.content_type.len = strlen(buckets->content_type_);
-      r->headers_out.content_type.data = (u_char*)buckets->content_type_;
+      r->headers_out.content_type.len = strlen(headers->content_type_);
+      r->headers_out.content_type.data = (u_char*)headers->content_type_;
     }
 
     // Nginx properly handles range requests, even when we're sending chunks
